# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/build/v1/build.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.builds import build_pb2 as qwak_dot_builds_dot_build__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19qwak/build/v1/build.proto\x12\x11\x63om.qwak.build.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17qwak/builds/build.proto\"\xda\x01\n\x0bModelSchema\x12+\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x19.com.qwak.build.v1.Entity\x12,\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32\x1a.com.qwak.build.v1.Feature\x12\x32\n\x0bpredictions\x18\x03 \x03(\x0b\x32\x1d.com.qwak.build.v1.Prediction\x12<\n\x10inference_output\x18\x04 \x03(\x0b\x32\".com.qwak.build.v1.InferenceOutput\"B\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"\xa8\x04\n\x07\x46\x65\x61ture\x12\x38\n\rbatch_feature\x18\x01 \x01(\x0b\x32\x1f.com.qwak.build.v1.BatchFeatureH\x00\x12>\n\x10\x65xplicit_feature\x18\x02 \x01(\x0b\x32\".com.qwak.build.v1.ExplicitFeatureH\x00\x12@\n\x12on_the_fly_feature\x18\x03 \x01(\x0b\x32\".com.qwak.build.v1.OnTheFlyFeatureH\x00\x12@\n\x11streaming_feature\x18\x04 \x01(\x0b\x32#.com.qwak.build.v1.StreamingFeatureH\x00\x12\x38\n\rrequest_input\x18\x05 \x01(\x0b\x32\x1f.com.qwak.build.v1.RequestInputH\x00\x12W\n\x1dstreaming_aggregation_feature\x18\x06 \x01(\x0b\x32..com.qwak.build.v1.StreamingAggregationFeatureH\x00\x12=\n\x10\x62\x61tch_feature_v1\x18\x07 \x01(\x0b\x32!.com.qwak.build.v1.BatchFeatureV1H\x00\x12\x45\n\x14streaming_feature_v1\x18\x08 \x01(\x0b\x32%.com.qwak.build.v1.StreamingFeatureV1H\x00\x42\x06\n\x04type\"\x85\x01\n\x0fOnTheFlyFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x39\n\x0fsource_features\x18\x03 \x03(\x0b\x32 .com.qwak.build.v1.SourceFeature\"I\n\x0e\x42\x61tchFeatureV1\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"M\n\x12StreamingFeatureV1\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"G\n\x0c\x42\x61tchFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"K\n\x10StreamingFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"V\n\x1bStreamingAggregationFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"K\n\x0f\x45xplicitFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"H\n\x0cRequestInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"\x91\x01\n\rSourceFeature\x12>\n\x10\x65xplicit_feature\x18\x01 \x01(\x0b\x32\".com.qwak.build.v1.ExplicitFeatureH\x00\x12\x38\n\rrequest_input\x18\x02 \x01(\x0b\x32\x1f.com.qwak.build.v1.RequestInputH\x00\x42\x06\n\x04type\"F\n\nPrediction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"K\n\x0fInferenceOutput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"\xa1\x01\n\tValueType\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".com.qwak.build.v1.ValueType.Types\"b\n\x05Types\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05\x42YTES\x10\x01\x12\n\n\x06STRING\x10\x02\x12\t\n\x05INT32\x10\x03\x12\t\n\x05INT64\x10\x04\x12\n\n\x06\x44OUBLE\x10\x05\x12\t\n\x05\x46LOAT\x10\x06\x12\x08\n\x04\x42OOL\x10\x07\"j\n\x11ParameterCategory\"U\n\x08\x43\x61tegory\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x45NTITY\x10\x01\x12\x0b\n\x07\x46\x45\x41TURE\x10\x02\x12\x0e\n\nPREDICTION\x10\x03\x12\x13\n\x0fINFERENCEOUTPUT\x10\x04\"\x9c\x07\n\x05\x42uild\x12\x0f\n\x07\x62uildId\x18\x01 \x01(\t\x12\x10\n\x08\x63ommitId\x18\x02 \x01(\t\x12\x10\n\x08\x62ranchId\x18\x03 \x01(\t\x12\x13\n\x0b\x62uildConfig\x18\x04 \x01(\t\x12\x34\n\x0c\x62uild_status\x18\x05 \x01(\x0e\x32\x1e.com.qwak.build.v1.BuildStatus\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12\r\n\x05steps\x18\x07 \x03(\t\x12\x34\n\x06params\x18\x08 \x03(\x0b\x32$.com.qwak.build.v1.Build.ParamsEntry\x12\x36\n\x07metrics\x18\t \x03(\x0b\x32%.com.qwak.build.v1.Build.MetricsEntry\x12\x34\n\x0cmodel_schema\x18\n \x01(\x0b\x32\x1e.com.qwak.build.v1.ModelSchema\x12\'\n\x05\x61udit\x18\x0b \x01(\x0b\x32\x18.com.qwak.build.v1.Audit\x12\x12\n\nmodel_uuid\x18\x0c \x01(\t\x12\x13\n\x0bsdk_version\x18\r \x01(\t\x12\x16\n\x0eimage_name_tag\x18\x0e \x01(\t\x12J\n\x1b\x62uild_configuration_message\x18\x0f \x01(\x0b\x32%.com.qwak.build.v1.BuildConfiguration\x12,\n\x08\x65nd_date\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x65nvironment_id\x18\x11 \x01(\t\x12\x1c\n\x14\x62uild_destined_image\x18\x12 \x01(\t\x12;\n\x10\x66ramework_models\x18\x13 \x03(\x0b\x32!.com.qwak.build.v1.FrameworkModel\x12(\n build_destined_image_pull_secret\x18\x14 \x01(\t\x12\x1b\n\x13\x66\x61ilure_reason_code\x18\x15 \x01(\t\x12\x12\n\nbuild_name\x18\x16 \x01(\t\x12\x15\n\rbuild_version\x18\x17 \x01(\x03\x12\x10\n\x08\x64uration\x18\x18 \x01(\x03\x12\x18\n\x10model_version_id\x18\x19 \x01(\t\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\x9b\x01\n\x05\x41udit\x12\x12\n\ncreated_by\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x03 \x01(\t\x12\x34\n\x10last_modified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb3\x02\n\x12\x42uildConfiguration\x12<\n\x10\x62uild_properties\x18\x01 \x01(\x0b\x32\".com.qwak.build.v1.BuildProperties\x12\x36\n\tbuild_env\x18\x02 \x01(\x0b\x32#.com.qwak.build.v1.BuildEnvironment\x12\x36\n\tpre_build\x18\x03 \x01(\x0b\x32#.com.qwak.build.v1.BuildEnvironment\x12\x37\n\npost_build\x18\x04 \x01(\x0b\x32#.com.qwak.build.v1.BuildEnvironment\x12%\n\x04step\x18\x05 \x01(\x0b\x32\x17.com.qwak.build.v1.Step\x12\x0f\n\x07verbose\x18\x06 \x01(\x05\"\xba\x01\n\x0f\x42uildProperties\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x33\n\tmodel_uri\x18\x02 \x01(\x0b\x32 .com.qwak.build.v1.BuildModelUri\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x10\n\x08\x62uild_id\x18\x04 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\x12\x18\n\x10\x65nvironment_name\x18\x06 \x01(\t\x12\x16\n\x0egpu_compatible\x18\x07 \x01(\x08\"g\n\rBuildModelUri\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x10\n\x08main_dir\x18\x03 \x01(\t\x12#\n\x1b\x64\x65pendency_required_folders\x18\x04 \x03(\t\"\xd4\x01\n\x10\x42uildEnvironment\x12.\n\x06\x64ocker\x18\x01 \x01(\x0b\x32\x1e.com.qwak.build.v1.DockerBuild\x12,\n\x05local\x18\x02 \x01(\x0b\x32\x1d.com.qwak.build.v1.LocalBuild\x12\x32\n\npython_env\x18\x03 \x01(\x0b\x32\x1e.com.qwak.build.v1.PythonBuild\x12.\n\x06remote\x18\x04 \x01(\x0b\x32\x1e.com.qwak.build.v1.RemoteBuild\"\xae\x02\n\x0b\x44ockerBuild\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x41\n\nbuild_args\x18\x02 \x03(\x0b\x32-.com.qwak.build.v1.DockerBuild.BuildArgsEntry\x12\x10\n\x08\x65nv_vars\x18\x03 \x03(\t\x12\x10\n\x08no_cache\x18\x04 \x01(\x08\x12\x0e\n\x06params\x18\x05 \x03(\t\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x06 \x01(\t\x12\r\n\x05\x63\x61\x63he\x18\x07 \x01(\x08\x12\x0c\n\x04push\x18\x08 \x01(\x08\x12\'\n\x1fservice_account_key_secret_name\x18\t \x01(\t\x1a\x30\n\x0e\x42uildArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\nLocalBuild\x12\x13\n\x0b\x61ws_profile\x18\x01 \x01(\t\x12\x0f\n\x07no_push\x18\x02 \x01(\x08\"\x8c\x02\n\x0bPythonBuild\x12 \n\x18qwak_sdk_extra_index_url\x18\x01 \x01(\t\x12>\n\nvirtualenv\x18\x02 \x01(\x0b\x32*.com.qwak.build.v1.VirtualEnvironmentBuild\x12,\n\x05\x63onda\x18\x03 \x01(\x0b\x32\x1d.com.qwak.build.v1.CondaBuild\x12.\n\x06poetry\x18\x04 \x01(\x0b\x32\x1e.com.qwak.build.v1.PoetryBuild\x12\x1c\n\x14\x64\x65pendency_file_path\x18\x05 \x01(\t\x12\x1f\n\x17use_deprecated_resolver\x18\x06 \x01(\x08\" \n\nCondaBuild\x12\x12\n\nconda_file\x18\x01 \x01(\t\"8\n\x0bPoetryBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x11\n\tlock_file\x18\x02 \x01(\t\"K\n\x17VirtualEnvironmentBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x18\n\x10requirements_txt\x18\x02 \x01(\t\"\\\n\x0bRemoteBuild\x12\x11\n\tis_remote\x18\x01 \x01(\x08\x12:\n\tresources\x18\x02 \x01(\x0b\x32\'.com.qwak.build.v1.RemoteBuildResources\"\x8f\x01\n\x14RemoteBuildResources\x12\x0c\n\x04\x63pus\x18\x01 \x01(\x02\x12\x0e\n\x06memory\x18\x02 \x01(\t\x12\x33\n\x08gpu_type\x18\x03 \x01(\x0e\x32!.qwak.builds.orchestrator.GpuType\x12\x12\n\ngpu_amount\x18\x04 \x01(\x05\x12\x10\n\x08instance\x18\x05 \x01(\t\"_\n\x04Step\x12\r\n\x05tests\x18\x01 \x01(\x08\x12\x1f\n\x17validate_build_artifact\x18\x02 \x01(\x08\x12\'\n\x1fvalidate_build_artifact_timeout\x18\x03 \x01(\x05\"\xf7\x01\n\x0b\x42uildFilter\x12\x0c\n\x04tags\x18\x01 \x03(\t\x12\x37\n\x0emetric_filters\x18\x02 \x03(\x0b\x32\x1f.com.qwak.build.v1.MetricFilter\x12=\n\x11parameter_filters\x18\x03 \x03(\x0b\x32\".com.qwak.build.v1.ParameterFilter\x12\x18\n\x10require_all_tags\x18\x04 \x01(\x08\x12\x1a\n\x12include_extra_tags\x18\x05 \x01(\x08\x12\x11\n\tbuild_ids\x18\x06 \x03(\t\x12\x19\n\x11model_version_ids\x18\x07 \x03(\t\"r\n\x0cMetricFilter\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12\x14\n\x0cmetric_value\x18\x02 \x01(\x02\x12\x37\n\x08operator\x18\x03 \x01(\x0e\x32%.com.qwak.build.v1.MetricOperatorType\"~\n\x0fParameterFilter\x12\x16\n\x0eparameter_name\x18\x01 \x01(\t\x12\x17\n\x0fparameter_value\x18\x02 \x01(\t\x12:\n\x08operator\x18\x03 \x01(\x0e\x32(.com.qwak.build.v1.ParameterOperatorType\"d\n\x13\x46rameworkModelsSpec\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12;\n\x10\x66ramework_models\x18\x02 \x03(\x0b\x32!.com.qwak.build.v1.FrameworkModel\"c\n\x0e\x46rameworkModel\x12I\n\x16huggingface_model_spec\x18\x02 \x01(\x0b\x32\'.com.qwak.build.v1.HuggingFaceModelSpecH\x00\x42\x06\n\x04type\"]\n\x14HuggingFaceModelSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x12\x12\n\nmodel_name\x18\x03 \x01(\t\x12\x0c\n\x04sha1\x18\x04 \x01(\t\"r\n\x11ScanResultSummary\x12(\n\x06issues\x18\x01 \x03(\x0b\x32\x18.com.qwak.build.v1.Issue\x12\x16\n\x0eui_direct_link\x18\x02 \x01(\t\x12\x1b\n\x13ui_scan_direct_link\x18\x03 \x01(\t\"a\n\x05Issue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08severity\x18\x02 \x01(\t\x12\x12\n\nissue_type\x18\x03 \x01(\t\x12\x0f\n\x07summary\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"L\n\x11\x42uildImageDetails\x12\x17\n\x0fimage_full_path\x18\x01 \x01(\t\x12\x1e\n\x16image_pull_secret_name\x18\x02 \x01(\t\"\x9b\x04\n\x0fScanRequestType\x12\\\n scan_software_components_request\x18\x01 \x01(\x0b\x32\x30.com.qwak.build.v1.ScanSoftwareComponentsRequestH\x00\x12U\n\x1cscan_vulnerabilities_request\x18\x02 \x01(\x0b\x32-.com.qwak.build.v1.ScanVulnerabilitiesRequestH\x00\x12Z\n\x1fscan_malicious_packages_request\x18\x03 \x01(\x0b\x32/.com.qwak.build.v1.ScanMaliciousPackagesRequestH\x00\x12X\n\x1escan_policy_violations_request\x18\x04 \x01(\x0b\x32..com.qwak.build.v1.ScanPolicyViolationsRequestH\x00\x12\x43\n\x13scan_status_request\x18\x05 \x01(\x0b\x32$.com.qwak.build.v1.ScanStatusRequestH\x00\x12P\n\x1ascan_feature_state_request\x18\x06 \x01(\x0b\x32*.com.qwak.build.v1.ScanFeatureStateRequestH\x00\x42\x06\n\x04type\"\x1f\n\x1dScanSoftwareComponentsRequest\"\x1c\n\x1aScanVulnerabilitiesRequest\"\x1e\n\x1cScanMaliciousPackagesRequest\"\x1d\n\x1bScanPolicyViolationsRequest\"\x13\n\x11ScanStatusRequest\"/\n\x17ScanFeatureStateRequest\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x01 \x01(\t*\xad\x02\n\x0b\x42uildStatus\x12\x0b\n\x07INVALID\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0e\n\nSUCCESSFUL\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x1d\n\x19REMOTE_BUILD_INITIALIZING\x10\x04\x12\x1a\n\x16REMOTE_BUILD_CANCELLED\x10\x05\x12\x1a\n\x16REMOTE_BUILD_TIMED_OUT\x10\x06\x12\x18\n\x14REMOTE_BUILD_UNKNOWN\x10\x07\x12\x18\n\x14SYNCING_ENVIRONMENTS\x10\x08\x12\x14\n\x10\x46INISHED_SYNCING\x10\t\x12\x13\n\x0f\x42UILD_REQUESTED\x10\n\x12\x11\n\rBUILD_PENDING\x10\x0b\x12\x1b\n\x17\x46\x41ILED_INITIATING_BUILD\x10\x0c*\xa0\x02\n\x12MetricOperatorType\x12 \n\x1cMETRIC_OPERATOR_TYPE_INVALID\x10\x00\x12\x1f\n\x1bMETRIC_OPERATOR_TYPE_EQUALS\x10\x01\x12#\n\x1fMETRIC_OPERATOR_TYPE_NOT_EQUALS\x10\x02\x12\"\n\x1eMETRIC_OPERATOR_TYPE_LESS_THAN\x10\x03\x12)\n%METRIC_OPERATOR_TYPE_LESS_THAN_EQUALS\x10\x04\x12%\n!METRIC_OPERATOR_TYPE_GREATER_THAN\x10\x05\x12,\n(METRIC_OPERATOR_TYPE_GREATER_THAN_EQUALS\x10\x06*\x88\x01\n\x15ParameterOperatorType\x12#\n\x1fPARAMETER_OPERATOR_TYPE_INVALID\x10\x00\x12\"\n\x1ePARAMETER_OPERATOR_TYPE_EQUALS\x10\x01\x12&\n\"PARAMETER_OPERATOR_TYPE_NOT_EQUALS\x10\x02\x42!\n\x11\x63om.qwak.build.v1B\nBuildProtoP\x01\x62\x06proto3')

_BUILDSTATUS = DESCRIPTOR.enum_types_by_name['BuildStatus']
BuildStatus = enum_type_wrapper.EnumTypeWrapper(_BUILDSTATUS)
_METRICOPERATORTYPE = DESCRIPTOR.enum_types_by_name['MetricOperatorType']
MetricOperatorType = enum_type_wrapper.EnumTypeWrapper(_METRICOPERATORTYPE)
_PARAMETEROPERATORTYPE = DESCRIPTOR.enum_types_by_name['ParameterOperatorType']
ParameterOperatorType = enum_type_wrapper.EnumTypeWrapper(_PARAMETEROPERATORTYPE)
INVALID = 0
IN_PROGRESS = 1
SUCCESSFUL = 2
FAILED = 3
REMOTE_BUILD_INITIALIZING = 4
REMOTE_BUILD_CANCELLED = 5
REMOTE_BUILD_TIMED_OUT = 6
REMOTE_BUILD_UNKNOWN = 7
SYNCING_ENVIRONMENTS = 8
FINISHED_SYNCING = 9
BUILD_REQUESTED = 10
BUILD_PENDING = 11
FAILED_INITIATING_BUILD = 12
METRIC_OPERATOR_TYPE_INVALID = 0
METRIC_OPERATOR_TYPE_EQUALS = 1
METRIC_OPERATOR_TYPE_NOT_EQUALS = 2
METRIC_OPERATOR_TYPE_LESS_THAN = 3
METRIC_OPERATOR_TYPE_LESS_THAN_EQUALS = 4
METRIC_OPERATOR_TYPE_GREATER_THAN = 5
METRIC_OPERATOR_TYPE_GREATER_THAN_EQUALS = 6
PARAMETER_OPERATOR_TYPE_INVALID = 0
PARAMETER_OPERATOR_TYPE_EQUALS = 1
PARAMETER_OPERATOR_TYPE_NOT_EQUALS = 2


_MODELSCHEMA = DESCRIPTOR.message_types_by_name['ModelSchema']
_ENTITY = DESCRIPTOR.message_types_by_name['Entity']
_FEATURE = DESCRIPTOR.message_types_by_name['Feature']
_ONTHEFLYFEATURE = DESCRIPTOR.message_types_by_name['OnTheFlyFeature']
_BATCHFEATUREV1 = DESCRIPTOR.message_types_by_name['BatchFeatureV1']
_STREAMINGFEATUREV1 = DESCRIPTOR.message_types_by_name['StreamingFeatureV1']
_BATCHFEATURE = DESCRIPTOR.message_types_by_name['BatchFeature']
_STREAMINGFEATURE = DESCRIPTOR.message_types_by_name['StreamingFeature']
_STREAMINGAGGREGATIONFEATURE = DESCRIPTOR.message_types_by_name['StreamingAggregationFeature']
_EXPLICITFEATURE = DESCRIPTOR.message_types_by_name['ExplicitFeature']
_REQUESTINPUT = DESCRIPTOR.message_types_by_name['RequestInput']
_SOURCEFEATURE = DESCRIPTOR.message_types_by_name['SourceFeature']
_PREDICTION = DESCRIPTOR.message_types_by_name['Prediction']
_INFERENCEOUTPUT = DESCRIPTOR.message_types_by_name['InferenceOutput']
_VALUETYPE = DESCRIPTOR.message_types_by_name['ValueType']
_PARAMETERCATEGORY = DESCRIPTOR.message_types_by_name['ParameterCategory']
_BUILD = DESCRIPTOR.message_types_by_name['Build']
_BUILD_PARAMSENTRY = _BUILD.nested_types_by_name['ParamsEntry']
_BUILD_METRICSENTRY = _BUILD.nested_types_by_name['MetricsEntry']
_AUDIT = DESCRIPTOR.message_types_by_name['Audit']
_BUILDCONFIGURATION = DESCRIPTOR.message_types_by_name['BuildConfiguration']
_BUILDPROPERTIES = DESCRIPTOR.message_types_by_name['BuildProperties']
_BUILDMODELURI = DESCRIPTOR.message_types_by_name['BuildModelUri']
_BUILDENVIRONMENT = DESCRIPTOR.message_types_by_name['BuildEnvironment']
_DOCKERBUILD = DESCRIPTOR.message_types_by_name['DockerBuild']
_DOCKERBUILD_BUILDARGSENTRY = _DOCKERBUILD.nested_types_by_name['BuildArgsEntry']
_LOCALBUILD = DESCRIPTOR.message_types_by_name['LocalBuild']
_PYTHONBUILD = DESCRIPTOR.message_types_by_name['PythonBuild']
_CONDABUILD = DESCRIPTOR.message_types_by_name['CondaBuild']
_POETRYBUILD = DESCRIPTOR.message_types_by_name['PoetryBuild']
_VIRTUALENVIRONMENTBUILD = DESCRIPTOR.message_types_by_name['VirtualEnvironmentBuild']
_REMOTEBUILD = DESCRIPTOR.message_types_by_name['RemoteBuild']
_REMOTEBUILDRESOURCES = DESCRIPTOR.message_types_by_name['RemoteBuildResources']
_STEP = DESCRIPTOR.message_types_by_name['Step']
_BUILDFILTER = DESCRIPTOR.message_types_by_name['BuildFilter']
_METRICFILTER = DESCRIPTOR.message_types_by_name['MetricFilter']
_PARAMETERFILTER = DESCRIPTOR.message_types_by_name['ParameterFilter']
_FRAMEWORKMODELSSPEC = DESCRIPTOR.message_types_by_name['FrameworkModelsSpec']
_FRAMEWORKMODEL = DESCRIPTOR.message_types_by_name['FrameworkModel']
_HUGGINGFACEMODELSPEC = DESCRIPTOR.message_types_by_name['HuggingFaceModelSpec']
_SCANRESULTSUMMARY = DESCRIPTOR.message_types_by_name['ScanResultSummary']
_ISSUE = DESCRIPTOR.message_types_by_name['Issue']
_BUILDIMAGEDETAILS = DESCRIPTOR.message_types_by_name['BuildImageDetails']
_SCANREQUESTTYPE = DESCRIPTOR.message_types_by_name['ScanRequestType']
_SCANSOFTWARECOMPONENTSREQUEST = DESCRIPTOR.message_types_by_name['ScanSoftwareComponentsRequest']
_SCANVULNERABILITIESREQUEST = DESCRIPTOR.message_types_by_name['ScanVulnerabilitiesRequest']
_SCANMALICIOUSPACKAGESREQUEST = DESCRIPTOR.message_types_by_name['ScanMaliciousPackagesRequest']
_SCANPOLICYVIOLATIONSREQUEST = DESCRIPTOR.message_types_by_name['ScanPolicyViolationsRequest']
_SCANSTATUSREQUEST = DESCRIPTOR.message_types_by_name['ScanStatusRequest']
_SCANFEATURESTATEREQUEST = DESCRIPTOR.message_types_by_name['ScanFeatureStateRequest']
_VALUETYPE_TYPES = _VALUETYPE.enum_types_by_name['Types']
_PARAMETERCATEGORY_CATEGORY = _PARAMETERCATEGORY.enum_types_by_name['Category']
ModelSchema = _reflection.GeneratedProtocolMessageType('ModelSchema', (_message.Message,), {
  'DESCRIPTOR' : _MODELSCHEMA,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ModelSchema)
  })
_sym_db.RegisterMessage(ModelSchema)

Entity = _reflection.GeneratedProtocolMessageType('Entity', (_message.Message,), {
  'DESCRIPTOR' : _ENTITY,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.Entity)
  })
_sym_db.RegisterMessage(Entity)

Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), {
  'DESCRIPTOR' : _FEATURE,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.Feature)
  })
_sym_db.RegisterMessage(Feature)

OnTheFlyFeature = _reflection.GeneratedProtocolMessageType('OnTheFlyFeature', (_message.Message,), {
  'DESCRIPTOR' : _ONTHEFLYFEATURE,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.OnTheFlyFeature)
  })
_sym_db.RegisterMessage(OnTheFlyFeature)

BatchFeatureV1 = _reflection.GeneratedProtocolMessageType('BatchFeatureV1', (_message.Message,), {
  'DESCRIPTOR' : _BATCHFEATUREV1,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.BatchFeatureV1)
  })
_sym_db.RegisterMessage(BatchFeatureV1)

StreamingFeatureV1 = _reflection.GeneratedProtocolMessageType('StreamingFeatureV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGFEATUREV1,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.StreamingFeatureV1)
  })
_sym_db.RegisterMessage(StreamingFeatureV1)

BatchFeature = _reflection.GeneratedProtocolMessageType('BatchFeature', (_message.Message,), {
  'DESCRIPTOR' : _BATCHFEATURE,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.BatchFeature)
  })
_sym_db.RegisterMessage(BatchFeature)

StreamingFeature = _reflection.GeneratedProtocolMessageType('StreamingFeature', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGFEATURE,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.StreamingFeature)
  })
_sym_db.RegisterMessage(StreamingFeature)

StreamingAggregationFeature = _reflection.GeneratedProtocolMessageType('StreamingAggregationFeature', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGAGGREGATIONFEATURE,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.StreamingAggregationFeature)
  })
_sym_db.RegisterMessage(StreamingAggregationFeature)

ExplicitFeature = _reflection.GeneratedProtocolMessageType('ExplicitFeature', (_message.Message,), {
  'DESCRIPTOR' : _EXPLICITFEATURE,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ExplicitFeature)
  })
_sym_db.RegisterMessage(ExplicitFeature)

RequestInput = _reflection.GeneratedProtocolMessageType('RequestInput', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTINPUT,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RequestInput)
  })
_sym_db.RegisterMessage(RequestInput)

SourceFeature = _reflection.GeneratedProtocolMessageType('SourceFeature', (_message.Message,), {
  'DESCRIPTOR' : _SOURCEFEATURE,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.SourceFeature)
  })
_sym_db.RegisterMessage(SourceFeature)

Prediction = _reflection.GeneratedProtocolMessageType('Prediction', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTION,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.Prediction)
  })
_sym_db.RegisterMessage(Prediction)

InferenceOutput = _reflection.GeneratedProtocolMessageType('InferenceOutput', (_message.Message,), {
  'DESCRIPTOR' : _INFERENCEOUTPUT,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.InferenceOutput)
  })
_sym_db.RegisterMessage(InferenceOutput)

ValueType = _reflection.GeneratedProtocolMessageType('ValueType', (_message.Message,), {
  'DESCRIPTOR' : _VALUETYPE,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ValueType)
  })
_sym_db.RegisterMessage(ValueType)

ParameterCategory = _reflection.GeneratedProtocolMessageType('ParameterCategory', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERCATEGORY,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ParameterCategory)
  })
_sym_db.RegisterMessage(ParameterCategory)

Build = _reflection.GeneratedProtocolMessageType('Build', (_message.Message,), {

  'ParamsEntry' : _reflection.GeneratedProtocolMessageType('ParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _BUILD_PARAMSENTRY,
    '__module__' : 'qwak.build.v1.build_pb2'
    # @@protoc_insertion_point(class_scope:com.qwak.build.v1.Build.ParamsEntry)
    })
  ,

  'MetricsEntry' : _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), {
    'DESCRIPTOR' : _BUILD_METRICSENTRY,
    '__module__' : 'qwak.build.v1.build_pb2'
    # @@protoc_insertion_point(class_scope:com.qwak.build.v1.Build.MetricsEntry)
    })
  ,
  'DESCRIPTOR' : _BUILD,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.Build)
  })
_sym_db.RegisterMessage(Build)
_sym_db.RegisterMessage(Build.ParamsEntry)
_sym_db.RegisterMessage(Build.MetricsEntry)

Audit = _reflection.GeneratedProtocolMessageType('Audit', (_message.Message,), {
  'DESCRIPTOR' : _AUDIT,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.Audit)
  })
_sym_db.RegisterMessage(Audit)

BuildConfiguration = _reflection.GeneratedProtocolMessageType('BuildConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _BUILDCONFIGURATION,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.BuildConfiguration)
  })
_sym_db.RegisterMessage(BuildConfiguration)

BuildProperties = _reflection.GeneratedProtocolMessageType('BuildProperties', (_message.Message,), {
  'DESCRIPTOR' : _BUILDPROPERTIES,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.BuildProperties)
  })
_sym_db.RegisterMessage(BuildProperties)

BuildModelUri = _reflection.GeneratedProtocolMessageType('BuildModelUri', (_message.Message,), {
  'DESCRIPTOR' : _BUILDMODELURI,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.BuildModelUri)
  })
_sym_db.RegisterMessage(BuildModelUri)

BuildEnvironment = _reflection.GeneratedProtocolMessageType('BuildEnvironment', (_message.Message,), {
  'DESCRIPTOR' : _BUILDENVIRONMENT,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.BuildEnvironment)
  })
_sym_db.RegisterMessage(BuildEnvironment)

DockerBuild = _reflection.GeneratedProtocolMessageType('DockerBuild', (_message.Message,), {

  'BuildArgsEntry' : _reflection.GeneratedProtocolMessageType('BuildArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DOCKERBUILD_BUILDARGSENTRY,
    '__module__' : 'qwak.build.v1.build_pb2'
    # @@protoc_insertion_point(class_scope:com.qwak.build.v1.DockerBuild.BuildArgsEntry)
    })
  ,
  'DESCRIPTOR' : _DOCKERBUILD,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.DockerBuild)
  })
_sym_db.RegisterMessage(DockerBuild)
_sym_db.RegisterMessage(DockerBuild.BuildArgsEntry)

LocalBuild = _reflection.GeneratedProtocolMessageType('LocalBuild', (_message.Message,), {
  'DESCRIPTOR' : _LOCALBUILD,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.LocalBuild)
  })
_sym_db.RegisterMessage(LocalBuild)

PythonBuild = _reflection.GeneratedProtocolMessageType('PythonBuild', (_message.Message,), {
  'DESCRIPTOR' : _PYTHONBUILD,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.PythonBuild)
  })
_sym_db.RegisterMessage(PythonBuild)

CondaBuild = _reflection.GeneratedProtocolMessageType('CondaBuild', (_message.Message,), {
  'DESCRIPTOR' : _CONDABUILD,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.CondaBuild)
  })
_sym_db.RegisterMessage(CondaBuild)

PoetryBuild = _reflection.GeneratedProtocolMessageType('PoetryBuild', (_message.Message,), {
  'DESCRIPTOR' : _POETRYBUILD,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.PoetryBuild)
  })
_sym_db.RegisterMessage(PoetryBuild)

VirtualEnvironmentBuild = _reflection.GeneratedProtocolMessageType('VirtualEnvironmentBuild', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALENVIRONMENTBUILD,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.VirtualEnvironmentBuild)
  })
_sym_db.RegisterMessage(VirtualEnvironmentBuild)

RemoteBuild = _reflection.GeneratedProtocolMessageType('RemoteBuild', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEBUILD,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RemoteBuild)
  })
_sym_db.RegisterMessage(RemoteBuild)

RemoteBuildResources = _reflection.GeneratedProtocolMessageType('RemoteBuildResources', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEBUILDRESOURCES,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.RemoteBuildResources)
  })
_sym_db.RegisterMessage(RemoteBuildResources)

Step = _reflection.GeneratedProtocolMessageType('Step', (_message.Message,), {
  'DESCRIPTOR' : _STEP,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.Step)
  })
_sym_db.RegisterMessage(Step)

BuildFilter = _reflection.GeneratedProtocolMessageType('BuildFilter', (_message.Message,), {
  'DESCRIPTOR' : _BUILDFILTER,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.BuildFilter)
  })
_sym_db.RegisterMessage(BuildFilter)

MetricFilter = _reflection.GeneratedProtocolMessageType('MetricFilter', (_message.Message,), {
  'DESCRIPTOR' : _METRICFILTER,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.MetricFilter)
  })
_sym_db.RegisterMessage(MetricFilter)

ParameterFilter = _reflection.GeneratedProtocolMessageType('ParameterFilter', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERFILTER,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ParameterFilter)
  })
_sym_db.RegisterMessage(ParameterFilter)

FrameworkModelsSpec = _reflection.GeneratedProtocolMessageType('FrameworkModelsSpec', (_message.Message,), {
  'DESCRIPTOR' : _FRAMEWORKMODELSSPEC,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.FrameworkModelsSpec)
  })
_sym_db.RegisterMessage(FrameworkModelsSpec)

FrameworkModel = _reflection.GeneratedProtocolMessageType('FrameworkModel', (_message.Message,), {
  'DESCRIPTOR' : _FRAMEWORKMODEL,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.FrameworkModel)
  })
_sym_db.RegisterMessage(FrameworkModel)

HuggingFaceModelSpec = _reflection.GeneratedProtocolMessageType('HuggingFaceModelSpec', (_message.Message,), {
  'DESCRIPTOR' : _HUGGINGFACEMODELSPEC,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.HuggingFaceModelSpec)
  })
_sym_db.RegisterMessage(HuggingFaceModelSpec)

ScanResultSummary = _reflection.GeneratedProtocolMessageType('ScanResultSummary', (_message.Message,), {
  'DESCRIPTOR' : _SCANRESULTSUMMARY,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ScanResultSummary)
  })
_sym_db.RegisterMessage(ScanResultSummary)

Issue = _reflection.GeneratedProtocolMessageType('Issue', (_message.Message,), {
  'DESCRIPTOR' : _ISSUE,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.Issue)
  })
_sym_db.RegisterMessage(Issue)

BuildImageDetails = _reflection.GeneratedProtocolMessageType('BuildImageDetails', (_message.Message,), {
  'DESCRIPTOR' : _BUILDIMAGEDETAILS,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.BuildImageDetails)
  })
_sym_db.RegisterMessage(BuildImageDetails)

ScanRequestType = _reflection.GeneratedProtocolMessageType('ScanRequestType', (_message.Message,), {
  'DESCRIPTOR' : _SCANREQUESTTYPE,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ScanRequestType)
  })
_sym_db.RegisterMessage(ScanRequestType)

ScanSoftwareComponentsRequest = _reflection.GeneratedProtocolMessageType('ScanSoftwareComponentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCANSOFTWARECOMPONENTSREQUEST,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ScanSoftwareComponentsRequest)
  })
_sym_db.RegisterMessage(ScanSoftwareComponentsRequest)

ScanVulnerabilitiesRequest = _reflection.GeneratedProtocolMessageType('ScanVulnerabilitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCANVULNERABILITIESREQUEST,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ScanVulnerabilitiesRequest)
  })
_sym_db.RegisterMessage(ScanVulnerabilitiesRequest)

ScanMaliciousPackagesRequest = _reflection.GeneratedProtocolMessageType('ScanMaliciousPackagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCANMALICIOUSPACKAGESREQUEST,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ScanMaliciousPackagesRequest)
  })
_sym_db.RegisterMessage(ScanMaliciousPackagesRequest)

ScanPolicyViolationsRequest = _reflection.GeneratedProtocolMessageType('ScanPolicyViolationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCANPOLICYVIOLATIONSREQUEST,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ScanPolicyViolationsRequest)
  })
_sym_db.RegisterMessage(ScanPolicyViolationsRequest)

ScanStatusRequest = _reflection.GeneratedProtocolMessageType('ScanStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCANSTATUSREQUEST,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ScanStatusRequest)
  })
_sym_db.RegisterMessage(ScanStatusRequest)

ScanFeatureStateRequest = _reflection.GeneratedProtocolMessageType('ScanFeatureStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCANFEATURESTATEREQUEST,
  '__module__' : 'qwak.build.v1.build_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build.v1.ScanFeatureStateRequest)
  })
_sym_db.RegisterMessage(ScanFeatureStateRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021com.qwak.build.v1B\nBuildProtoP\001'
  _BUILD_PARAMSENTRY._options = None
  _BUILD_PARAMSENTRY._serialized_options = b'8\001'
  _BUILD_METRICSENTRY._options = None
  _BUILD_METRICSENTRY._serialized_options = b'8\001'
  _DOCKERBUILD_BUILDARGSENTRY._options = None
  _DOCKERBUILD_BUILDARGSENTRY._serialized_options = b'8\001'
  _BUILDSTATUS._serialized_start=7060
  _BUILDSTATUS._serialized_end=7361
  _METRICOPERATORTYPE._serialized_start=7364
  _METRICOPERATORTYPE._serialized_end=7652
  _PARAMETEROPERATORTYPE._serialized_start=7655
  _PARAMETEROPERATORTYPE._serialized_end=7791
  _MODELSCHEMA._serialized_start=107
  _MODELSCHEMA._serialized_end=325
  _ENTITY._serialized_start=327
  _ENTITY._serialized_end=393
  _FEATURE._serialized_start=396
  _FEATURE._serialized_end=948
  _ONTHEFLYFEATURE._serialized_start=951
  _ONTHEFLYFEATURE._serialized_end=1084
  _BATCHFEATUREV1._serialized_start=1086
  _BATCHFEATUREV1._serialized_end=1159
  _STREAMINGFEATUREV1._serialized_start=1161
  _STREAMINGFEATUREV1._serialized_end=1238
  _BATCHFEATURE._serialized_start=1240
  _BATCHFEATURE._serialized_end=1311
  _STREAMINGFEATURE._serialized_start=1313
  _STREAMINGFEATURE._serialized_end=1388
  _STREAMINGAGGREGATIONFEATURE._serialized_start=1390
  _STREAMINGAGGREGATIONFEATURE._serialized_end=1476
  _EXPLICITFEATURE._serialized_start=1478
  _EXPLICITFEATURE._serialized_end=1553
  _REQUESTINPUT._serialized_start=1555
  _REQUESTINPUT._serialized_end=1627
  _SOURCEFEATURE._serialized_start=1630
  _SOURCEFEATURE._serialized_end=1775
  _PREDICTION._serialized_start=1777
  _PREDICTION._serialized_end=1847
  _INFERENCEOUTPUT._serialized_start=1849
  _INFERENCEOUTPUT._serialized_end=1924
  _VALUETYPE._serialized_start=1927
  _VALUETYPE._serialized_end=2088
  _VALUETYPE_TYPES._serialized_start=1990
  _VALUETYPE_TYPES._serialized_end=2088
  _PARAMETERCATEGORY._serialized_start=2090
  _PARAMETERCATEGORY._serialized_end=2196
  _PARAMETERCATEGORY_CATEGORY._serialized_start=2111
  _PARAMETERCATEGORY_CATEGORY._serialized_end=2196
  _BUILD._serialized_start=2199
  _BUILD._serialized_end=3123
  _BUILD_PARAMSENTRY._serialized_start=3030
  _BUILD_PARAMSENTRY._serialized_end=3075
  _BUILD_METRICSENTRY._serialized_start=3077
  _BUILD_METRICSENTRY._serialized_end=3123
  _AUDIT._serialized_start=3126
  _AUDIT._serialized_end=3281
  _BUILDCONFIGURATION._serialized_start=3284
  _BUILDCONFIGURATION._serialized_end=3591
  _BUILDPROPERTIES._serialized_start=3594
  _BUILDPROPERTIES._serialized_end=3780
  _BUILDMODELURI._serialized_start=3782
  _BUILDMODELURI._serialized_end=3885
  _BUILDENVIRONMENT._serialized_start=3888
  _BUILDENVIRONMENT._serialized_end=4100
  _DOCKERBUILD._serialized_start=4103
  _DOCKERBUILD._serialized_end=4405
  _DOCKERBUILD_BUILDARGSENTRY._serialized_start=4357
  _DOCKERBUILD_BUILDARGSENTRY._serialized_end=4405
  _LOCALBUILD._serialized_start=4407
  _LOCALBUILD._serialized_end=4457
  _PYTHONBUILD._serialized_start=4460
  _PYTHONBUILD._serialized_end=4728
  _CONDABUILD._serialized_start=4730
  _CONDABUILD._serialized_end=4762
  _POETRYBUILD._serialized_start=4764
  _POETRYBUILD._serialized_end=4820
  _VIRTUALENVIRONMENTBUILD._serialized_start=4822
  _VIRTUALENVIRONMENTBUILD._serialized_end=4897
  _REMOTEBUILD._serialized_start=4899
  _REMOTEBUILD._serialized_end=4991
  _REMOTEBUILDRESOURCES._serialized_start=4994
  _REMOTEBUILDRESOURCES._serialized_end=5137
  _STEP._serialized_start=5139
  _STEP._serialized_end=5234
  _BUILDFILTER._serialized_start=5237
  _BUILDFILTER._serialized_end=5484
  _METRICFILTER._serialized_start=5486
  _METRICFILTER._serialized_end=5600
  _PARAMETERFILTER._serialized_start=5602
  _PARAMETERFILTER._serialized_end=5728
  _FRAMEWORKMODELSSPEC._serialized_start=5730
  _FRAMEWORKMODELSSPEC._serialized_end=5830
  _FRAMEWORKMODEL._serialized_start=5832
  _FRAMEWORKMODEL._serialized_end=5931
  _HUGGINGFACEMODELSPEC._serialized_start=5933
  _HUGGINGFACEMODELSPEC._serialized_end=6026
  _SCANRESULTSUMMARY._serialized_start=6028
  _SCANRESULTSUMMARY._serialized_end=6142
  _ISSUE._serialized_start=6144
  _ISSUE._serialized_end=6241
  _BUILDIMAGEDETAILS._serialized_start=6243
  _BUILDIMAGEDETAILS._serialized_end=6319
  _SCANREQUESTTYPE._serialized_start=6322
  _SCANREQUESTTYPE._serialized_end=6861
  _SCANSOFTWARECOMPONENTSREQUEST._serialized_start=6863
  _SCANSOFTWARECOMPONENTSREQUEST._serialized_end=6894
  _SCANVULNERABILITIESREQUEST._serialized_start=6896
  _SCANVULNERABILITIESREQUEST._serialized_end=6924
  _SCANMALICIOUSPACKAGESREQUEST._serialized_start=6926
  _SCANMALICIOUSPACKAGESREQUEST._serialized_end=6956
  _SCANPOLICYVIOLATIONSREQUEST._serialized_start=6958
  _SCANPOLICYVIOLATIONSREQUEST._serialized_end=6987
  _SCANSTATUSREQUEST._serialized_start=6989
  _SCANSTATUSREQUEST._serialized_end=7008
  _SCANFEATURESTATEREQUEST._serialized_start=7010
  _SCANFEATURESTATEREQUEST._serialized_end=7057
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/repository/common/platform.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3qwak/feature_store/repository/common/platform.proto\x12$qwak.feature.store.repository.common\"\xb6\x01\n\x10PlatformSettings\x12S\n\x12repository_setting\x18\x01 \x01(\x0b\x32\x37.qwak.feature.store.repository.common.RepositorySetting\x12M\n\x0fproject_setting\x18\x02 \x01(\x0b\x32\x34.qwak.feature.store.repository.common.ProjectSetting\"+\n\x11RepositorySetting\x12\x16\n\x0erepository_key\x18\x01 \x01(\t\"=\n\x0eProjectSetting\x12\x15\n\x0bproject_key\x18\x02 \x01(\tH\x00\x42\x14\n\x12project_identifierBj\n/com.qwak.ai.feature.store.repository.common.apiP\x01Z5qwak/featurestore/source/repository;source_repositoryb\x06proto3')



_PLATFORMSETTINGS = DESCRIPTOR.message_types_by_name['PlatformSettings']
_REPOSITORYSETTING = DESCRIPTOR.message_types_by_name['RepositorySetting']
_PROJECTSETTING = DESCRIPTOR.message_types_by_name['ProjectSetting']
PlatformSettings = _reflection.GeneratedProtocolMessageType('PlatformSettings', (_message.Message,), {
  'DESCRIPTOR' : _PLATFORMSETTINGS,
  '__module__' : 'qwak.feature_store.repository.common.platform_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.repository.common.PlatformSettings)
  })
_sym_db.RegisterMessage(PlatformSettings)

RepositorySetting = _reflection.GeneratedProtocolMessageType('RepositorySetting', (_message.Message,), {
  'DESCRIPTOR' : _REPOSITORYSETTING,
  '__module__' : 'qwak.feature_store.repository.common.platform_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.repository.common.RepositorySetting)
  })
_sym_db.RegisterMessage(RepositorySetting)

ProjectSetting = _reflection.GeneratedProtocolMessageType('ProjectSetting', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTSETTING,
  '__module__' : 'qwak.feature_store.repository.common.platform_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.repository.common.ProjectSetting)
  })
_sym_db.RegisterMessage(ProjectSetting)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n/com.qwak.ai.feature.store.repository.common.apiP\001Z5qwak/featurestore/source/repository;source_repository'
  _PLATFORMSETTINGS._serialized_start=94
  _PLATFORMSETTINGS._serialized_end=276
  _REPOSITORYSETTING._serialized_start=278
  _REPOSITORYSETTING._serialized_end=321
  _PROJECTSETTING._serialized_start=323
  _PROJECTSETTING._serialized_end=384
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ValueV1(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_SET_FIELD_NUMBER: builtins.int
    BYTES_VAL_FIELD_NUMBER: builtins.int
    STRING_VAL_FIELD_NUMBER: builtins.int
    INT32_VAL_FIELD_NUMBER: builtins.int
    INT64_VAL_FIELD_NUMBER: builtins.int
    DOUBLE_VAL_FIELD_NUMBER: builtins.int
    FLOAT_VAL_FIELD_NUMBER: builtins.int
    BOOL_VAL_FIELD_NUMBER: builtins.int
    TIMESTAMP_VAL_FIELD_NUMBER: builtins.int
    ARRAY_VAL_FIELD_NUMBER: builtins.int
    is_set: builtins.bool
    """indicates whether a value is actually present OR null.
    without this flag we can't represent a null integer/ null item in an array etc.

    to set a null value for some type, set the "val" oneof to that type (the value
    itself doesn't matter in that case) and is_set to False.
    to set a non-null value, set the value (with the type), set is_set to True.
    """
    bytes_val: builtins.bytes
    string_val: builtins.str
    int32_val: builtins.int
    int64_val: builtins.int
    double_val: builtins.float
    float_val: builtins.float
    bool_val: builtins.bool
    @property
    def timestamp_val(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def array_val(self) -> global___ArrayV1: ...
    def __init__(
        self,
        *,
        is_set: builtins.bool = ...,
        bytes_val: builtins.bytes = ...,
        string_val: builtins.str = ...,
        int32_val: builtins.int = ...,
        int64_val: builtins.int = ...,
        double_val: builtins.float = ...,
        float_val: builtins.float = ...,
        bool_val: builtins.bool = ...,
        timestamp_val: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        array_val: global___ArrayV1 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["array_val", b"array_val", "bool_val", b"bool_val", "bytes_val", b"bytes_val", "double_val", b"double_val", "float_val", b"float_val", "int32_val", b"int32_val", "int64_val", b"int64_val", "string_val", b"string_val", "timestamp_val", b"timestamp_val", "val", b"val"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["array_val", b"array_val", "bool_val", b"bool_val", "bytes_val", b"bytes_val", "double_val", b"double_val", "float_val", b"float_val", "int32_val", b"int32_val", "int64_val", b"int64_val", "is_set", b"is_set", "string_val", b"string_val", "timestamp_val", b"timestamp_val", "val", b"val"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["val", b"val"]) -> typing_extensions.Literal["bytes_val", "string_val", "int32_val", "int64_val", "double_val", "float_val", "bool_val", "timestamp_val", "array_val"] | None: ...

global___ValueV1 = ValueV1

class ArrayV1(google.protobuf.message.Message):
    """Note: this way of representing Arrays is a bit permissive -
    one can set an array where each cell has a different type.
    as a result, do not assume this array is necessarily valid, and add
    validation checks if necessary.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARRAY_VAL_FIELD_NUMBER: builtins.int
    @property
    def array_val(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValueV1]: ...
    def __init__(
        self,
        *,
        array_val: collections.abc.Iterable[global___ValueV1] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["array_val", b"array_val"]) -> None: ...

global___ArrayV1 = ArrayV1



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.builds.build_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BuildInitDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SPEC_FIELD_NUMBER: builtins.int
    INITIATOR_FIELD_NUMBER: builtins.int
    @property
    def build_spec(self) -> qwak.builds.build_pb2.RemoteBuildSpec:
        """Requested build model spec"""
    @property
    def initiator(self) -> qwak.builds.build_pb2.BuildInitiator:
        """override to the initiator of the build"""
    def __init__(
        self,
        *,
        build_spec: qwak.builds.build_pb2.RemoteBuildSpec | None = ...,
        initiator: qwak.builds.build_pb2.BuildInitiator | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec", "initiator", b"initiator"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec", "initiator", b"initiator"]) -> None: ...

global___BuildInitDetails = BuildInitDetails

class InternalBuildModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_INIT_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def build_init_details(self) -> global___BuildInitDetails:
        """The request of build"""
    def __init__(
        self,
        *,
        build_init_details: global___BuildInitDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_init_details", b"build_init_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_init_details", b"build_init_details"]) -> None: ...

global___InternalBuildModelRequest = InternalBuildModelRequest

class InternalBuildModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___InternalBuildModelResponse = InternalBuildModelResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.fitness_service.fitness_pb2
import qwak.fitness_service.status_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BuildModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SPEC_FIELD_NUMBER: builtins.int
    @property
    def build_spec(self) -> qwak.fitness_service.fitness_pb2.BuildSpec:
        """Requested build model spec"""
    def __init__(
        self,
        *,
        build_spec: qwak.fitness_service.fitness_pb2.BuildSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec"]) -> None: ...

global___BuildModelRequest = BuildModelRequest

class BuildModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___BuildModelResponse = BuildModelResponse

class CancelBuildModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """Build id of the build to cancel"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___CancelBuildModelRequest = CancelBuildModelRequest

class CancelBuildModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CancelBuildModelResponse = CancelBuildModelResponse

class GetRemoteBuildingStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """Build id of the build to get status for"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___GetRemoteBuildingStatusRequest = GetRemoteBuildingStatusRequest

class GetRemoteBuildingStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> qwak.fitness_service.status_pb2.RemoteBuildingStatus: ...
    def __init__(
        self,
        *,
        status: qwak.fitness_service.status_pb2.RemoteBuildingStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___GetRemoteBuildingStatusResponse = GetRemoteBuildingStatusResponse

class CleanRemoteBuildResourcesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___CleanRemoteBuildResourcesRequest = CleanRemoteBuildResourcesRequest

class CleanRemoteBuildResourcesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CleanRemoteBuildResourcesResponse = CleanRemoteBuildResourcesResponse



from __future__ import annotations

import os
import shutil
import tempfile
from contextlib import contextmanager
from pathlib import Path
from typing import Optional, Union

from qwak.exceptions import QwakException
from qwak.inner.build_logic.interface.build_logger_interface import BuildLogger

from qwak.exceptions import QwakSuggestionException
from qwak.inner.build_logic.tools.files import copytree

try:
    from git import Repo
    from git.exc import GitError
except ImportError:
    pass

from ..strategy import Strategy, get_ignore_pattern


class GitStrategy(Strategy):
    def fetch(
        self,
        src: Union[str, Path],
        dest: str,
        git_branch: str,
        git_credentials: str,
        custom_dependencies_path: str,
        main_dir: str,
        git_ssh_key: str,
        **kwargs,
    ) -> str:
        self.build_logger.debug(f"Fetching Model code from git repository -  {src}")
        with tempfile.TemporaryDirectory() as clone_dest:
            with ssh_key_context(git_ssh_key):
                git_url, git_subdirectory = split_git_url_and_subdirectory(uri=src)
                self.build_logger.debug(
                    f"Fetching model code from git {git_url}, Model located in {git_subdirectory}"
                )
                git_commit_id = self.clone_and_checkout_repo(
                    clone_dest=clone_dest,
                    git_url=git_url,
                    git_branch=git_branch,
                    git_credentials=git_credentials,
                )
                self.copy_model(
                    clone_dest=clone_dest,
                    git_subdirectory=git_subdirectory,
                    model_dest=dest,
                    custom_dependencies_path=custom_dependencies_path,
                    main_dir=main_dir,
                )

        return git_commit_id

    def clone_and_checkout_repo(
        self,
        clone_dest: str,
        git_url: str,
        git_branch: str,
        git_credentials: str,
    ) -> str:
        git_remote_url = get_git_remote_uri(
            self.build_logger,
            url=git_url,
            git_credentials=git_credentials,
        )
        git_commit_id = clone_and_checkout_repo(
            git_repo_url=git_remote_url, to_path=clone_dest, git_branch=git_branch
        )

        return git_commit_id

    def copy_model(
        self,
        clone_dest: str,
        git_subdirectory: str,
        model_dest: str,
        custom_dependencies_path: Optional[str],
        main_dir: str,
    ):
        ignore_patterns, patterns_for_printing = get_ignore_pattern(
            Path(clone_dest) / git_subdirectory, main_dir, self.build_logger
        )
        self.build_logger.debug(
            f"Will ignore the following files: {patterns_for_printing}."
        )

        # Copy model
        copytree(
            src=Path(clone_dest) / git_subdirectory,
            dst=model_dest,
            dirs_exist_ok=True,
            ignore=ignore_patterns,
        )
        self.build_logger.debug("Model copied from git repository")

        # Copy custom dependencies path
        if custom_dependencies_path:
            git_custom_dependencies_path = Path(clone_dest) / Path(
                custom_dependencies_path
            )
            if git_custom_dependencies_path.is_file():
                shutil.copy(
                    src=git_custom_dependencies_path,
                    dst=Path(model_dest) / git_custom_dependencies_path.name,
                )
                self.build_logger.debug(
                    "Custom dependency file copied from git repository"
                )


def split_git_url_and_subdirectory(uri):
    subdirectory = ""
    parsed_uri = uri
    if "#" in uri:
        subdirectory = uri[uri.find("#") + 1 :]
        parsed_uri = uri[: uri.find("#")]
    if subdirectory and "." in subdirectory:
        raise QwakException("'.' is not allowed in project subdirectory paths.")
    return parsed_uri, subdirectory


def get_git_remote_uri(
    build_logger: BuildLogger, url: str, git_credentials: str
) -> str:
    if git_credentials:
        url_start_index = url.find("://") + 3
        url = f"{url[:url_start_index]}{git_credentials}@{url[url_start_index:]}"
    else:
        build_logger.warning("Git credentials secret has been provided")

    return url


@contextmanager
def ssh_key_context(git_ssh_key: str):
    ssh_key_path = None
    if git_ssh_key:
        ssh_key_path = make_ssh_key_file(git_ssh_key)
        add_ssh_file_to_env(ssh_key_path)
    try:
        yield
    finally:
        if ssh_key_path:
            try:
                os.remove(ssh_key_path)
            except OSError as e:
                QwakException(f"Failed to delete ssh key temp key file: {e}")


def make_ssh_key_file(git_ssh_key: str) -> str:
    with tempfile.NamedTemporaryFile(
        delete=False, mode="w", encoding="utf-8"
    ) as temp_file:
        temp_file.write(git_ssh_key + "\n")
    temp_file_path = temp_file.name
    return temp_file_path


def add_ssh_file_to_env(ssh_key_file_path: str) -> None:
    os.environ[
        "GIT_SSH_COMMAND"
    ] = f"ssh -i {ssh_key_file_path} -o StrictHostKeyChecking=no"
    os.environ["GIT_SSH"] = f"ssh -i {ssh_key_file_path} -o StrictHostKeyChecking=no"


def clone_and_checkout_repo(git_repo_url: str, to_path: str, git_branch: str) -> str:
    try:
        repo = Repo.clone_from(url=git_repo_url, to_path=to_path)
        repo.submodule_update(init=True, recursive=True)
        if git_branch in repo.branches:
            repo.git.checkout(git_branch)
        else:
            repo.git.checkout("-b", git_branch, f"{repo.remote()}/{git_branch}")
        return repo.head.object.hexsha
    except GitError as e:
        raise QwakSuggestionException(
            src_exception=e,
            message="Unable to clone git repository",
            suggestion="Please check you git credentials",
        )



from qwak.inner.runtime_di.containers import QwakRuntimeContainer, ContainerLock


def wire_runtime():
    container = QwakRuntimeContainer()
    from qwak.model import decorators

    container.wire(
        packages=[
            decorators,
        ]
    )
    return container



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/batch.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&qwak/feature_store/sources/batch.proto\x12\x1aqwak.feature.store.sources\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd9\x06\n\x0b\x42\x61tchSource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x61te_created_column\x18\x03 \x01(\t\x12@\n\x0c\x61thenaSource\x18\x04 \x01(\x0b\x32(.qwak.feature.store.sources.AthenaSourceH\x00\x12>\n\x0bmongoSource\x18\x05 \x01(\x0b\x32\'.qwak.feature.store.sources.MongoSourceH\x00\x12:\n\tcsvSource\x18\x06 \x01(\x0b\x32%.qwak.feature.store.sources.CsvSourceH\x00\x12\x46\n\x0fsnowflakeSource\x18\x07 \x01(\x0b\x32+.qwak.feature.store.sources.SnowflakeSourceH\x00\x12\x42\n\rparquetSource\x18\x08 \x01(\x0b\x32).qwak.feature.store.sources.ParquetSourceH\x00\x12<\n\njdbcSource\x18\t \x01(\x0b\x32&.qwak.feature.store.sources.JdbcSourceH\x00\x12\x42\n\rverticaSource\x18\n \x01(\x0b\x32).qwak.feature.store.sources.VerticaSourceH\x00\x12\x44\n\x0e\x62igquerySource\x18\x0b \x01(\x0b\x32*.qwak.feature.store.sources.BigquerySourceH\x00\x12N\n\x13\x65lasticsearchSource\x18\x0c \x01(\x0b\x32/.qwak.feature.store.sources.ElasticsearchSourceH\x00\x12H\n\x10\x63lickhouseSource\x18\r \x01(\x0b\x32,.qwak.feature.store.sources.ClickhouseSourceH\x00\x12V\n\x17\x66\x65\x61turesetOfflineSource\x18\x0e \x01(\x0b\x32\x33.qwak.feature.store.sources.FeaturesetOfflineSourceH\x00\x42\x06\n\x04type\"\xae\x04\n\x17\x46ileSystemConfiguration\x12X\n\x14\x61ws_s3_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.sources.AwsS3FileSystemConfigurationH\x00\x12P\n\x10\x61ws_s3_anonymous\x18\x02 \x01(\x0b\x32\x34.qwak.feature.store.sources.AnonymousS3ConfigurationH\x00\x12W\n aws_s3_assume_role_configuration\x18\x03 \x01(\x0b\x32+.qwak.feature.store.sources.AwsS3AssumeRoleH\x00\x12M\n\x13gcs_unauthenticated\x18\x04 \x01(\x0b\x32..qwak.feature.store.sources.GcsUnauthenticatedH\x00\x12N\n\x14gcs_user_credentials\x18\x05 \x01(\x0b\x32..qwak.feature.store.sources.GcsUserCredentialsH\x00\x12g\n!gcs_service_account_impersonation\x18\x06 \x01(\x0b\x32:.qwak.feature.store.sources.GcsServiceAccountImpersonationH\x00\x42\x06\n\x04type\"#\n\x0f\x41wsS3AssumeRole\x12\x10\n\x08role_arn\x18\x01 \x01(\t\"\x91\x01\n\x1c\x41wsS3FileSystemConfiguration\x12\x1e\n\x16\x61\x63\x63\x65ss_key_secret_name\x18\x01 \x01(\t\x12\x1e\n\x16secret_key_secret_name\x18\x02 \x01(\t\x12!\n\x19session_token_secret_name\x18\x03 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x04 \x01(\t\"\x1a\n\x18\x41nonymousS3Configuration\"\x92\x03\n\nJdbcSource\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x1c\n\x14username_secret_name\x18\x01 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x02 \x01(\t\x12\x10\n\x08\x64\x62_table\x18\x04 \x01(\t\x12\r\n\x05query\x18\x05 \x01(\t\x12>\n\x0bmysqlSource\x18\x06 \x01(\x0b\x32\'.qwak.feature.store.sources.MysqlSourceH\x00\x12H\n\x10postgresqlSource\x18\x07 \x01(\x0b\x32,.qwak.feature.store.sources.PostgresqlSourceH\x00\x12\x44\n\x0eredshiftSource\x18\x08 \x01(\x0b\x32*.qwak.feature.store.sources.RedshiftSourceH\x00\x12\x42\n\x0c\x61thenaSource\x18\t \x01(\x0b\x32*.qwak.feature.store.sources.AthenaSourceV1H\x00\x42\x06\n\x04type\"\r\n\x0bMysqlSource\"\x12\n\x10PostgresqlSource\"\x89\x01\n\x10\x43lickhouseSource\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x1c\n\x14username_secret_name\x18\x02 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x03 \x01(\t\x12\x0f\n\x05table\x18\x04 \x01(\tH\x00\x12\r\n\x03sql\x18\x05 \x01(\tH\x00\x42\x0c\n\nquery_type\"i\n\x0eRedshiftSource\x12\x0f\n\x07\x64\x62_user\x18\x01 \x01(\t\x12\x14\n\x0ciam_role_arn\x18\x02 \x01(\t\x12\x15\n\raccess_key_id\x18\x03 \x01(\t\x12\x19\n\x11secret_access_key\x18\x04 \x01(\t\"\x8d\x03\n\x0e\x41thenaSourceV1\x12\x12\n\naws_region\x18\x01 \x01(\t\x12I\n\x12\x61ws_authentication\x18\x02 \x01(\x0b\x32-.qwak.feature.store.sources.AwsAuthentication\x12\x1a\n\x12s3_output_location\x18\x03 \x01(\t\x12R\n\x16\x64\x61te_partition_columns\x18\x04 \x01(\x0b\x32\x30.qwak.feature.store.sources.DatePartitionColumnsH\x00\x12g\n!time_fragmented_partition_columns\x18\x05 \x01(\x0b\x32:.qwak.feature.store.sources.TimeFragmentedPartitionColumnsH\x00\x12\x13\n\tworkgroup\x18\x06 \x01(\tH\x01\x42\x18\n\x16time_partition_columnsB\x14\n\x12optional_workgroup\"E\n\x14\x44\x61tePartitionColumns\x12\x18\n\x10\x64\x61te_column_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61te_format\x18\x02 \x01(\t\"\xb5\x02\n\x1eTimeFragmentedPartitionColumns\x12M\n\x15year_partition_column\x18\x01 \x01(\x0b\x32..qwak.feature.store.sources.YearFragmentColumn\x12Q\n\x16month_partition_column\x18\x02 \x01(\x0b\x32/.qwak.feature.store.sources.MonthFragmentColumnH\x00\x12M\n\x14\x64\x61y_partition_column\x18\x03 \x01(\x0b\x32-.qwak.feature.store.sources.DayFragmentColumnH\x01\x42\x11\n\x0fmonth_partitionB\x0f\n\rday_partition\"\xa4\x01\n\x12YearFragmentColumn\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12`\n\x1dnumeric_column_representation\x18\x02 \x01(\x0b\x32\x37.qwak.feature.store.sources.NumericColumnRepresentationH\x00\x42\x17\n\x15\x63olumn_representation\"\x87\x02\n\x13MonthFragmentColumn\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12`\n\x1dnumeric_column_representation\x18\x02 \x01(\x0b\x32\x37.qwak.feature.store.sources.NumericColumnRepresentationH\x00\x12`\n\x1dtextual_column_representation\x18\x03 \x01(\x0b\x32\x37.qwak.feature.store.sources.TextualColumnRepresentationH\x00\x42\x17\n\x15\x63olumn_representation\"\xa3\x01\n\x11\x44\x61yFragmentColumn\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12`\n\x1dnumeric_column_representation\x18\x02 \x01(\x0b\x32\x37.qwak.feature.store.sources.NumericColumnRepresentationH\x00\x42\x17\n\x15\x63olumn_representation\"\x1d\n\x1bNumericColumnRepresentation\"\x1d\n\x1bTextualColumnRepresentation\"/\n\x0c\x41thenaSource\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\r\n\x05table\x18\x02 \x01(\t\"\xa0\x02\n\x0e\x42igquerySource\x12\x1f\n\x17\x63redentials_secret_name\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x61taset\x18\x02 \x01(\t\x12\r\n\x05table\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x16\n\x0eparent_project\x18\x05 \x01(\t\x12\x0b\n\x03sql\x18\x06 \x01(\t\x12\x15\n\rviews_enabled\x18\x07 \x01(\x08\x12#\n\x17materialization_dataset\x18\x08 \x01(\tB\x02\x18\x01\x12#\n\x17materialization_project\x18\t \x01(\tB\x02\x18\x01\x12\x36\n*materialization_expiration_time_in_minutes\x18\n \x01(\tB\x02\x18\x01\"\xa3\x01\n\tCsvSource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x17\n\x0fquote_character\x18\x02 \x01(\t\x12\x18\n\x10\x65scape_character\x18\x03 \x01(\t\x12U\n\x18\x66ilesystem_configuration\x18\x04 \x01(\x0b\x32\x33.qwak.feature.store.sources.FileSystemConfiguration\"\xab\x01\n\x0bMongoSource\x12\r\n\x05hosts\x18\x01 \x01(\t\x12\x1c\n\x14username_secret_name\x18\x02 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x03 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x04 \x01(\t\x12\x12\n\ncollection\x18\x05 \x01(\t\x12\x19\n\x11\x63onnection_params\x18\x06 \x01(\t\x12\x10\n\x08protocol\x18\x07 \x01(\t\"\xae\x01\n\x0fSnowflakeSource\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x1c\n\x14username_secret_name\x18\x02 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x03 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x04 \x01(\t\x12\x0e\n\x06schema\x18\x05 \x01(\t\x12\x11\n\twarehouse\x18\x06 \x01(\t\x12\r\n\x05table\x18\x07 \x01(\t\x12\r\n\x05query\x18\x08 \x01(\t\"t\n\rParquetSource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12U\n\x18\x66ilesystem_configuration\x18\x02 \x01(\x0b\x32\x33.qwak.feature.store.sources.FileSystemConfiguration\"\x98\x01\n\rVerticaSource\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x10\n\x08\x64\x61tabase\x18\x03 \x01(\t\x12\x0e\n\x06schema\x18\x04 \x01(\t\x12\r\n\x05table\x18\x05 \x01(\t\x12\x1c\n\x14username_secret_name\x18\x06 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x07 \x01(\t\"\xbc\x01\n\x13\x45lasticsearchSource\x12\r\n\x05nodes\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x10\n\x08resource\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12\x16\n\x0e\x65xclude_fields\x18\x05 \x01(\t\x12\x13\n\x0bparse_dates\x18\x06 \x01(\x08\x12\x1c\n\x14username_secret_name\x18\x07 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x08 \x01(\t\"(\n\x17\x46\x65\x61turesetOfflineSource\x12\r\n\x05\x61lias\x18\x01 \x01(\t\"\xe9\x01\n\x11\x41wsAuthentication\x12\x61\n\x1e\x61ws_assume_role_authentication\x18\x01 \x01(\x0b\x32\x37.qwak.feature.store.sources.AwsAssumeRoleAuthenticationH\x00\x12i\n%aws_static_credentials_authentication\x18\x02 \x01(\x0b\x32\x38.qwak.feature.store.sources.AwsCredentialsAuthenticationH\x00\x42\x06\n\x04type\"/\n\x1b\x41wsAssumeRoleAuthentication\x12\x10\n\x08role_arn\x18\x01 \x01(\t\"^\n\x1c\x41wsCredentialsAuthentication\x12\x1e\n\x16\x61\x63\x63\x65ss_key_secret_name\x18\x01 \x01(\t\x12\x1e\n\x16secret_key_secret_name\x18\x02 \x01(\t\"\x14\n\x12GcsUnauthenticated\"y\n\x12GcsUserCredentials\x12\x1d\n\x15\x63lient_id_secret_name\x18\x01 \x01(\t\x12!\n\x19\x63lient_secret_secret_name\x18\x02 \x01(\t\x12!\n\x19refresh_token_secret_name\x18\x03 \x01(\t\">\n\x1eGcsServiceAccountImpersonation\x12\x1c\n\x14service_account_user\x18\x01 \x01(\tBX\n%com.qwak.ai.feature.store.sources.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')



_BATCHSOURCE = DESCRIPTOR.message_types_by_name['BatchSource']
_FILESYSTEMCONFIGURATION = DESCRIPTOR.message_types_by_name['FileSystemConfiguration']
_AWSS3ASSUMEROLE = DESCRIPTOR.message_types_by_name['AwsS3AssumeRole']
_AWSS3FILESYSTEMCONFIGURATION = DESCRIPTOR.message_types_by_name['AwsS3FileSystemConfiguration']
_ANONYMOUSS3CONFIGURATION = DESCRIPTOR.message_types_by_name['AnonymousS3Configuration']
_JDBCSOURCE = DESCRIPTOR.message_types_by_name['JdbcSource']
_MYSQLSOURCE = DESCRIPTOR.message_types_by_name['MysqlSource']
_POSTGRESQLSOURCE = DESCRIPTOR.message_types_by_name['PostgresqlSource']
_CLICKHOUSESOURCE = DESCRIPTOR.message_types_by_name['ClickhouseSource']
_REDSHIFTSOURCE = DESCRIPTOR.message_types_by_name['RedshiftSource']
_ATHENASOURCEV1 = DESCRIPTOR.message_types_by_name['AthenaSourceV1']
_DATEPARTITIONCOLUMNS = DESCRIPTOR.message_types_by_name['DatePartitionColumns']
_TIMEFRAGMENTEDPARTITIONCOLUMNS = DESCRIPTOR.message_types_by_name['TimeFragmentedPartitionColumns']
_YEARFRAGMENTCOLUMN = DESCRIPTOR.message_types_by_name['YearFragmentColumn']
_MONTHFRAGMENTCOLUMN = DESCRIPTOR.message_types_by_name['MonthFragmentColumn']
_DAYFRAGMENTCOLUMN = DESCRIPTOR.message_types_by_name['DayFragmentColumn']
_NUMERICCOLUMNREPRESENTATION = DESCRIPTOR.message_types_by_name['NumericColumnRepresentation']
_TEXTUALCOLUMNREPRESENTATION = DESCRIPTOR.message_types_by_name['TextualColumnRepresentation']
_ATHENASOURCE = DESCRIPTOR.message_types_by_name['AthenaSource']
_BIGQUERYSOURCE = DESCRIPTOR.message_types_by_name['BigquerySource']
_CSVSOURCE = DESCRIPTOR.message_types_by_name['CsvSource']
_MONGOSOURCE = DESCRIPTOR.message_types_by_name['MongoSource']
_SNOWFLAKESOURCE = DESCRIPTOR.message_types_by_name['SnowflakeSource']
_PARQUETSOURCE = DESCRIPTOR.message_types_by_name['ParquetSource']
_VERTICASOURCE = DESCRIPTOR.message_types_by_name['VerticaSource']
_ELASTICSEARCHSOURCE = DESCRIPTOR.message_types_by_name['ElasticsearchSource']
_FEATURESETOFFLINESOURCE = DESCRIPTOR.message_types_by_name['FeaturesetOfflineSource']
_AWSAUTHENTICATION = DESCRIPTOR.message_types_by_name['AwsAuthentication']
_AWSASSUMEROLEAUTHENTICATION = DESCRIPTOR.message_types_by_name['AwsAssumeRoleAuthentication']
_AWSCREDENTIALSAUTHENTICATION = DESCRIPTOR.message_types_by_name['AwsCredentialsAuthentication']
_GCSUNAUTHENTICATED = DESCRIPTOR.message_types_by_name['GcsUnauthenticated']
_GCSUSERCREDENTIALS = DESCRIPTOR.message_types_by_name['GcsUserCredentials']
_GCSSERVICEACCOUNTIMPERSONATION = DESCRIPTOR.message_types_by_name['GcsServiceAccountImpersonation']
BatchSource = _reflection.GeneratedProtocolMessageType('BatchSource', (_message.Message,), {
  'DESCRIPTOR' : _BATCHSOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.BatchSource)
  })
_sym_db.RegisterMessage(BatchSource)

FileSystemConfiguration = _reflection.GeneratedProtocolMessageType('FileSystemConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _FILESYSTEMCONFIGURATION,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.FileSystemConfiguration)
  })
_sym_db.RegisterMessage(FileSystemConfiguration)

AwsS3AssumeRole = _reflection.GeneratedProtocolMessageType('AwsS3AssumeRole', (_message.Message,), {
  'DESCRIPTOR' : _AWSS3ASSUMEROLE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.AwsS3AssumeRole)
  })
_sym_db.RegisterMessage(AwsS3AssumeRole)

AwsS3FileSystemConfiguration = _reflection.GeneratedProtocolMessageType('AwsS3FileSystemConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _AWSS3FILESYSTEMCONFIGURATION,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.AwsS3FileSystemConfiguration)
  })
_sym_db.RegisterMessage(AwsS3FileSystemConfiguration)

AnonymousS3Configuration = _reflection.GeneratedProtocolMessageType('AnonymousS3Configuration', (_message.Message,), {
  'DESCRIPTOR' : _ANONYMOUSS3CONFIGURATION,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.AnonymousS3Configuration)
  })
_sym_db.RegisterMessage(AnonymousS3Configuration)

JdbcSource = _reflection.GeneratedProtocolMessageType('JdbcSource', (_message.Message,), {
  'DESCRIPTOR' : _JDBCSOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.JdbcSource)
  })
_sym_db.RegisterMessage(JdbcSource)

MysqlSource = _reflection.GeneratedProtocolMessageType('MysqlSource', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLSOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.MysqlSource)
  })
_sym_db.RegisterMessage(MysqlSource)

PostgresqlSource = _reflection.GeneratedProtocolMessageType('PostgresqlSource', (_message.Message,), {
  'DESCRIPTOR' : _POSTGRESQLSOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.PostgresqlSource)
  })
_sym_db.RegisterMessage(PostgresqlSource)

ClickhouseSource = _reflection.GeneratedProtocolMessageType('ClickhouseSource', (_message.Message,), {
  'DESCRIPTOR' : _CLICKHOUSESOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.ClickhouseSource)
  })
_sym_db.RegisterMessage(ClickhouseSource)

RedshiftSource = _reflection.GeneratedProtocolMessageType('RedshiftSource', (_message.Message,), {
  'DESCRIPTOR' : _REDSHIFTSOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.RedshiftSource)
  })
_sym_db.RegisterMessage(RedshiftSource)

AthenaSourceV1 = _reflection.GeneratedProtocolMessageType('AthenaSourceV1', (_message.Message,), {
  'DESCRIPTOR' : _ATHENASOURCEV1,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.AthenaSourceV1)
  })
_sym_db.RegisterMessage(AthenaSourceV1)

DatePartitionColumns = _reflection.GeneratedProtocolMessageType('DatePartitionColumns', (_message.Message,), {
  'DESCRIPTOR' : _DATEPARTITIONCOLUMNS,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DatePartitionColumns)
  })
_sym_db.RegisterMessage(DatePartitionColumns)

TimeFragmentedPartitionColumns = _reflection.GeneratedProtocolMessageType('TimeFragmentedPartitionColumns', (_message.Message,), {
  'DESCRIPTOR' : _TIMEFRAGMENTEDPARTITIONCOLUMNS,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.TimeFragmentedPartitionColumns)
  })
_sym_db.RegisterMessage(TimeFragmentedPartitionColumns)

YearFragmentColumn = _reflection.GeneratedProtocolMessageType('YearFragmentColumn', (_message.Message,), {
  'DESCRIPTOR' : _YEARFRAGMENTCOLUMN,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.YearFragmentColumn)
  })
_sym_db.RegisterMessage(YearFragmentColumn)

MonthFragmentColumn = _reflection.GeneratedProtocolMessageType('MonthFragmentColumn', (_message.Message,), {
  'DESCRIPTOR' : _MONTHFRAGMENTCOLUMN,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.MonthFragmentColumn)
  })
_sym_db.RegisterMessage(MonthFragmentColumn)

DayFragmentColumn = _reflection.GeneratedProtocolMessageType('DayFragmentColumn', (_message.Message,), {
  'DESCRIPTOR' : _DAYFRAGMENTCOLUMN,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DayFragmentColumn)
  })
_sym_db.RegisterMessage(DayFragmentColumn)

NumericColumnRepresentation = _reflection.GeneratedProtocolMessageType('NumericColumnRepresentation', (_message.Message,), {
  'DESCRIPTOR' : _NUMERICCOLUMNREPRESENTATION,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.NumericColumnRepresentation)
  })
_sym_db.RegisterMessage(NumericColumnRepresentation)

TextualColumnRepresentation = _reflection.GeneratedProtocolMessageType('TextualColumnRepresentation', (_message.Message,), {
  'DESCRIPTOR' : _TEXTUALCOLUMNREPRESENTATION,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.TextualColumnRepresentation)
  })
_sym_db.RegisterMessage(TextualColumnRepresentation)

AthenaSource = _reflection.GeneratedProtocolMessageType('AthenaSource', (_message.Message,), {
  'DESCRIPTOR' : _ATHENASOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.AthenaSource)
  })
_sym_db.RegisterMessage(AthenaSource)

BigquerySource = _reflection.GeneratedProtocolMessageType('BigquerySource', (_message.Message,), {
  'DESCRIPTOR' : _BIGQUERYSOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.BigquerySource)
  })
_sym_db.RegisterMessage(BigquerySource)

CsvSource = _reflection.GeneratedProtocolMessageType('CsvSource', (_message.Message,), {
  'DESCRIPTOR' : _CSVSOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.CsvSource)
  })
_sym_db.RegisterMessage(CsvSource)

MongoSource = _reflection.GeneratedProtocolMessageType('MongoSource', (_message.Message,), {
  'DESCRIPTOR' : _MONGOSOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.MongoSource)
  })
_sym_db.RegisterMessage(MongoSource)

SnowflakeSource = _reflection.GeneratedProtocolMessageType('SnowflakeSource', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKESOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.SnowflakeSource)
  })
_sym_db.RegisterMessage(SnowflakeSource)

ParquetSource = _reflection.GeneratedProtocolMessageType('ParquetSource', (_message.Message,), {
  'DESCRIPTOR' : _PARQUETSOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.ParquetSource)
  })
_sym_db.RegisterMessage(ParquetSource)

VerticaSource = _reflection.GeneratedProtocolMessageType('VerticaSource', (_message.Message,), {
  'DESCRIPTOR' : _VERTICASOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.VerticaSource)
  })
_sym_db.RegisterMessage(VerticaSource)

ElasticsearchSource = _reflection.GeneratedProtocolMessageType('ElasticsearchSource', (_message.Message,), {
  'DESCRIPTOR' : _ELASTICSEARCHSOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.ElasticsearchSource)
  })
_sym_db.RegisterMessage(ElasticsearchSource)

FeaturesetOfflineSource = _reflection.GeneratedProtocolMessageType('FeaturesetOfflineSource', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETOFFLINESOURCE,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.FeaturesetOfflineSource)
  })
_sym_db.RegisterMessage(FeaturesetOfflineSource)

AwsAuthentication = _reflection.GeneratedProtocolMessageType('AwsAuthentication', (_message.Message,), {
  'DESCRIPTOR' : _AWSAUTHENTICATION,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.AwsAuthentication)
  })
_sym_db.RegisterMessage(AwsAuthentication)

AwsAssumeRoleAuthentication = _reflection.GeneratedProtocolMessageType('AwsAssumeRoleAuthentication', (_message.Message,), {
  'DESCRIPTOR' : _AWSASSUMEROLEAUTHENTICATION,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.AwsAssumeRoleAuthentication)
  })
_sym_db.RegisterMessage(AwsAssumeRoleAuthentication)

AwsCredentialsAuthentication = _reflection.GeneratedProtocolMessageType('AwsCredentialsAuthentication', (_message.Message,), {
  'DESCRIPTOR' : _AWSCREDENTIALSAUTHENTICATION,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.AwsCredentialsAuthentication)
  })
_sym_db.RegisterMessage(AwsCredentialsAuthentication)

GcsUnauthenticated = _reflection.GeneratedProtocolMessageType('GcsUnauthenticated', (_message.Message,), {
  'DESCRIPTOR' : _GCSUNAUTHENTICATED,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.GcsUnauthenticated)
  })
_sym_db.RegisterMessage(GcsUnauthenticated)

GcsUserCredentials = _reflection.GeneratedProtocolMessageType('GcsUserCredentials', (_message.Message,), {
  'DESCRIPTOR' : _GCSUSERCREDENTIALS,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.GcsUserCredentials)
  })
_sym_db.RegisterMessage(GcsUserCredentials)

GcsServiceAccountImpersonation = _reflection.GeneratedProtocolMessageType('GcsServiceAccountImpersonation', (_message.Message,), {
  'DESCRIPTOR' : _GCSSERVICEACCOUNTIMPERSONATION,
  '__module__' : 'qwak.feature_store.sources.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.GcsServiceAccountImpersonation)
  })
_sym_db.RegisterMessage(GcsServiceAccountImpersonation)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.sources.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _BIGQUERYSOURCE.fields_by_name['materialization_dataset']._options = None
  _BIGQUERYSOURCE.fields_by_name['materialization_dataset']._serialized_options = b'\030\001'
  _BIGQUERYSOURCE.fields_by_name['materialization_project']._options = None
  _BIGQUERYSOURCE.fields_by_name['materialization_project']._serialized_options = b'\030\001'
  _BIGQUERYSOURCE.fields_by_name['materialization_expiration_time_in_minutes']._options = None
  _BIGQUERYSOURCE.fields_by_name['materialization_expiration_time_in_minutes']._serialized_options = b'\030\001'
  _BATCHSOURCE._serialized_start=104
  _BATCHSOURCE._serialized_end=961
  _FILESYSTEMCONFIGURATION._serialized_start=964
  _FILESYSTEMCONFIGURATION._serialized_end=1522
  _AWSS3ASSUMEROLE._serialized_start=1524
  _AWSS3ASSUMEROLE._serialized_end=1559
  _AWSS3FILESYSTEMCONFIGURATION._serialized_start=1562
  _AWSS3FILESYSTEMCONFIGURATION._serialized_end=1707
  _ANONYMOUSS3CONFIGURATION._serialized_start=1709
  _ANONYMOUSS3CONFIGURATION._serialized_end=1735
  _JDBCSOURCE._serialized_start=1738
  _JDBCSOURCE._serialized_end=2140
  _MYSQLSOURCE._serialized_start=2142
  _MYSQLSOURCE._serialized_end=2155
  _POSTGRESQLSOURCE._serialized_start=2157
  _POSTGRESQLSOURCE._serialized_end=2175
  _CLICKHOUSESOURCE._serialized_start=2178
  _CLICKHOUSESOURCE._serialized_end=2315
  _REDSHIFTSOURCE._serialized_start=2317
  _REDSHIFTSOURCE._serialized_end=2422
  _ATHENASOURCEV1._serialized_start=2425
  _ATHENASOURCEV1._serialized_end=2822
  _DATEPARTITIONCOLUMNS._serialized_start=2824
  _DATEPARTITIONCOLUMNS._serialized_end=2893
  _TIMEFRAGMENTEDPARTITIONCOLUMNS._serialized_start=2896
  _TIMEFRAGMENTEDPARTITIONCOLUMNS._serialized_end=3205
  _YEARFRAGMENTCOLUMN._serialized_start=3208
  _YEARFRAGMENTCOLUMN._serialized_end=3372
  _MONTHFRAGMENTCOLUMN._serialized_start=3375
  _MONTHFRAGMENTCOLUMN._serialized_end=3638
  _DAYFRAGMENTCOLUMN._serialized_start=3641
  _DAYFRAGMENTCOLUMN._serialized_end=3804
  _NUMERICCOLUMNREPRESENTATION._serialized_start=3806
  _NUMERICCOLUMNREPRESENTATION._serialized_end=3835
  _TEXTUALCOLUMNREPRESENTATION._serialized_start=3837
  _TEXTUALCOLUMNREPRESENTATION._serialized_end=3866
  _ATHENASOURCE._serialized_start=3868
  _ATHENASOURCE._serialized_end=3915
  _BIGQUERYSOURCE._serialized_start=3918
  _BIGQUERYSOURCE._serialized_end=4206
  _CSVSOURCE._serialized_start=4209
  _CSVSOURCE._serialized_end=4372
  _MONGOSOURCE._serialized_start=4375
  _MONGOSOURCE._serialized_end=4546
  _SNOWFLAKESOURCE._serialized_start=4549
  _SNOWFLAKESOURCE._serialized_end=4723
  _PARQUETSOURCE._serialized_start=4725
  _PARQUETSOURCE._serialized_end=4841
  _VERTICASOURCE._serialized_start=4844
  _VERTICASOURCE._serialized_end=4996
  _ELASTICSEARCHSOURCE._serialized_start=4999
  _ELASTICSEARCHSOURCE._serialized_end=5187
  _FEATURESETOFFLINESOURCE._serialized_start=5189
  _FEATURESETOFFLINESOURCE._serialized_end=5229
  _AWSAUTHENTICATION._serialized_start=5232
  _AWSAUTHENTICATION._serialized_end=5465
  _AWSASSUMEROLEAUTHENTICATION._serialized_start=5467
  _AWSASSUMEROLEAUTHENTICATION._serialized_end=5514
  _AWSCREDENTIALSAUTHENTICATION._serialized_start=5516
  _AWSCREDENTIALSAUTHENTICATION._serialized_end=5610
  _GCSUNAUTHENTICATED._serialized_start=5612
  _GCSUNAUTHENTICATED._serialized_end=5632
  _GCSUSERCREDENTIALS._serialized_start=5634
  _GCSUSERCREDENTIALS._serialized_end=5755
  _GCSSERVICEACCOUNTIMPERSONATION._serialized_start=5757
  _GCSSERVICEACCOUNTIMPERSONATION._serialized_end=5819
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.feature_store.jobs.v1.job_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DeleteFeaturesetJobByJobIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """Featureset id"""
    environment_id: builtins.str
    """Environment id"""
    job_id: builtins.str
    """Job id"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id", "job_id", b"job_id"]) -> None: ...

global___DeleteFeaturesetJobByJobIdRequest = DeleteFeaturesetJobByJobIdRequest

class DeleteFeaturesetJobByJobIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_JOB_RECORD_COUNT_FIELD_NUMBER: builtins.int
    deleted_job_record_count: builtins.int
    def __init__(
        self,
        *,
        deleted_job_record_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deleted_job_record_count", b"deleted_job_record_count"]) -> None: ...

global___DeleteFeaturesetJobByJobIdResponse = DeleteFeaturesetJobByJobIdResponse

class ApplyJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RECORD_FIELD_NUMBER: builtins.int
    @property
    def job_record(self) -> qwak.feature_store.jobs.v1.job_pb2.JobRecord:
        """The job record to register"""
    def __init__(
        self,
        *,
        job_record: qwak.feature_store.jobs.v1.job_pb2.JobRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job_record", b"job_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_record", b"job_record"]) -> None: ...

global___ApplyJobRequest = ApplyJobRequest

class ApplyJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RUNNING_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    job_running_id: builtins.int
    """Job running id"""
    job_id: builtins.str
    """Job Id"""
    def __init__(
        self,
        *,
        job_running_id: builtins.int = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_id", b"job_id", "job_running_id", b"job_running_id"]) -> None: ...

global___ApplyJobResponse = ApplyJobResponse

class InitPaginationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """The featureset id of the requested job records"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id"]) -> None: ...

global___InitPaginationRequest = InitPaginationRequest

class InitPaginationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_COUNT_FIELD_NUMBER: builtins.int
    PAGINATION_SESSION_MAX_ID_FIELD_NUMBER: builtins.int
    record_count: builtins.int
    """The amount of records that exist for this pagination session (current total amount of records for the featureset)"""
    pagination_session_max_id: builtins.int
    """The record to use for the max pagination sessions id in the ListJobs request"""
    def __init__(
        self,
        *,
        record_count: builtins.int = ...,
        pagination_session_max_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination_session_max_id", b"pagination_session_max_id", "record_count", b"record_count"]) -> None: ...

global___InitPaginationResponse = InitPaginationResponse

class ListJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    PAGINATION_SESSION_MAX_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """The featureset id of the requested job records"""
    environment_id: builtins.str
    """Environment id"""
    page_size: builtins.int
    """The amount of records to send in the result set"""
    page_number: builtins.int
    """The page number to get"""
    pagination_session_max_id: builtins.int
    """The max session record id from which we retrieve the data, if unset (defaults to 0) we return the first records"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_number: builtins.int = ...,
        pagination_session_max_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id", "page_number", b"page_number", "page_size", b"page_size", "pagination_session_max_id", b"pagination_session_max_id"]) -> None: ...

global___ListJobsRequest = ListJobsRequest

class ListJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.jobs.v1.job_pb2.JobRecord]:
        """Result set of the requested jobs"""
    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[qwak.feature_store.jobs.v1.job_pb2.JobRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jobs", b"jobs"]) -> None: ...

global___ListJobsResponse = ListJobsResponse

class GetLatestSuccessfulJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """The featureset id of the requested latest successful job record"""
    environment_id: builtins.str
    """The jobs' environment id"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id"]) -> None: ...

global___GetLatestSuccessfulJobRequest = GetLatestSuccessfulJobRequest

class GetLatestJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """The featureset id of the requested latest job record running"""
    environment_id: builtins.str
    """The jobs' environment id"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id"]) -> None: ...

global___GetLatestJobRequest = GetLatestJobRequest

class GetLatestJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_FIELD_NUMBER: builtins.int
    @property
    def job(self) -> qwak.feature_store.jobs.v1.job_pb2.JobRecord:
        """the requested job"""
    def __init__(
        self,
        *,
        job: qwak.feature_store.jobs.v1.job_pb2.JobRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job", b"job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["job", b"job"]) -> None: ...

global___GetLatestJobResponse = GetLatestJobResponse

class GetLatestSuccessfulJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_FIELD_NUMBER: builtins.int
    FOUND_FIELD_NUMBER: builtins.int
    @property
    def job(self) -> qwak.feature_store.jobs.v1.job_pb2.JobRecord:
        """the requested job"""
    found: builtins.bool
    """is the job empty or not"""
    def __init__(
        self,
        *,
        job: qwak.feature_store.jobs.v1.job_pb2.JobRecord | None = ...,
        found: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job", b"job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["found", b"found", "job", b"job"]) -> None: ...

global___GetLatestSuccessfulJobResponse = GetLatestSuccessfulJobResponse

class GetAllLatestSuccessfulJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetAllLatestSuccessfulJobsRequest = GetAllLatestSuccessfulJobsRequest

class GetAllLatestSuccessfulJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.jobs.v1.job_pb2.JobRecord]:
        """all latest requested jobs"""
    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[qwak.feature_store.jobs.v1.job_pb2.JobRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jobs", b"jobs"]) -> None: ...

global___GetAllLatestSuccessfulJobsResponse = GetAllLatestSuccessfulJobsResponse

class DeleteFeaturesetJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """The featureset id of the requested delete featureset jobs"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id"]) -> None: ...

global___DeleteFeaturesetJobsRequest = DeleteFeaturesetJobsRequest

class DeleteFeaturesetJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_JOB_RECORDS_COUNT_FIELD_NUMBER: builtins.int
    deleted_job_records_count: builtins.int
    def __init__(
        self,
        *,
        deleted_job_records_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deleted_job_records_count", b"deleted_job_records_count"]) -> None: ...

global___DeleteFeaturesetJobsResponse = DeleteFeaturesetJobsResponse

class GetJobsSummariesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOWER_TIME_BOUND_FIELD_NUMBER: builtins.int
    UPPER_TIME_BOUND_FIELD_NUMBER: builtins.int
    @property
    def lower_time_bound(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Summary lower time bound"""
    @property
    def upper_time_bound(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        lower_time_bound: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        upper_time_bound: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lower_time_bound", b"lower_time_bound", "upper_bound", b"upper_bound", "upper_time_bound", b"upper_time_bound"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lower_time_bound", b"lower_time_bound", "upper_bound", b"upper_bound", "upper_time_bound", b"upper_time_bound"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["upper_bound", b"upper_bound"]) -> typing_extensions.Literal["upper_time_bound"] | None: ...

global___GetJobsSummariesRequest = GetJobsSummariesRequest

class GetJobsSummariesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_SUMMARIES_FIELD_NUMBER: builtins.int
    @property
    def jobs_summaries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.jobs.v1.job_pb2.FeaturesetLevelJobsSummary]:
        """Job summaries per featureset for the entire environment"""
    def __init__(
        self,
        *,
        jobs_summaries: collections.abc.Iterable[qwak.feature_store.jobs.v1.job_pb2.FeaturesetLevelJobsSummary] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jobs_summaries", b"jobs_summaries"]) -> None: ...

global___GetJobsSummariesResponse = GetJobsSummariesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/build_settings/build_settings_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.build_settings import build_settings_pb2 as qwak_dot_build__settings_dot_build__settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/build_settings/build_settings_api.proto\x12\x17\x63om.qwak.build_settings\x1a(qwak/build_settings/build_settings.proto\"r\n\x18SaveBuildSettingsRequest\x12>\n\x0e\x62uild_settings\x18\x01 \x01(\x0b\x32&.com.qwak.build_settings.BuildSettings\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x03(\t\"6\n\x19SaveBuildSettingsResponse\x12\x19\n\x11\x62uild_settings_id\x18\x01 \x03(\t\"1\n\x17GetBuildSettingsRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"Z\n\x18GetBuildSettingsResponse\x12>\n\x0e\x62uild_settings\x18\x01 \x01(\x0b\x32&.com.qwak.build_settings.BuildSettings\"4\n\x1a\x44\x65leteBuildSettingsRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"\x1d\n\x1b\x44\x65leteBuildSettingsResponse2\x8a\x03\n\x10\x42uildSettingsApi\x12z\n\x11SaveBuildSettings\x12\x31.com.qwak.build_settings.SaveBuildSettingsRequest\x1a\x32.com.qwak.build_settings.SaveBuildSettingsResponse\x12w\n\x10GetBuildSettings\x12\x30.com.qwak.build_settings.GetBuildSettingsRequest\x1a\x31.com.qwak.build_settings.GetBuildSettingsResponse\x12\x80\x01\n\x13\x44\x65leteBuildSettings\x12\x33.com.qwak.build_settings.DeleteBuildSettingsRequest\x1a\x34.com.qwak.build_settings.DeleteBuildSettingsResponseB2\n\x17\x63om.qwak.build_settingsB\x15\x42uildSettingsApiProtoP\x01\x62\x06proto3')



_SAVEBUILDSETTINGSREQUEST = DESCRIPTOR.message_types_by_name['SaveBuildSettingsRequest']
_SAVEBUILDSETTINGSRESPONSE = DESCRIPTOR.message_types_by_name['SaveBuildSettingsResponse']
_GETBUILDSETTINGSREQUEST = DESCRIPTOR.message_types_by_name['GetBuildSettingsRequest']
_GETBUILDSETTINGSRESPONSE = DESCRIPTOR.message_types_by_name['GetBuildSettingsResponse']
_DELETEBUILDSETTINGSREQUEST = DESCRIPTOR.message_types_by_name['DeleteBuildSettingsRequest']
_DELETEBUILDSETTINGSRESPONSE = DESCRIPTOR.message_types_by_name['DeleteBuildSettingsResponse']
SaveBuildSettingsRequest = _reflection.GeneratedProtocolMessageType('SaveBuildSettingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVEBUILDSETTINGSREQUEST,
  '__module__' : 'qwak.build_settings.build_settings_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build_settings.SaveBuildSettingsRequest)
  })
_sym_db.RegisterMessage(SaveBuildSettingsRequest)

SaveBuildSettingsResponse = _reflection.GeneratedProtocolMessageType('SaveBuildSettingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAVEBUILDSETTINGSRESPONSE,
  '__module__' : 'qwak.build_settings.build_settings_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build_settings.SaveBuildSettingsResponse)
  })
_sym_db.RegisterMessage(SaveBuildSettingsResponse)

GetBuildSettingsRequest = _reflection.GeneratedProtocolMessageType('GetBuildSettingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUILDSETTINGSREQUEST,
  '__module__' : 'qwak.build_settings.build_settings_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build_settings.GetBuildSettingsRequest)
  })
_sym_db.RegisterMessage(GetBuildSettingsRequest)

GetBuildSettingsResponse = _reflection.GeneratedProtocolMessageType('GetBuildSettingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBUILDSETTINGSRESPONSE,
  '__module__' : 'qwak.build_settings.build_settings_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build_settings.GetBuildSettingsResponse)
  })
_sym_db.RegisterMessage(GetBuildSettingsResponse)

DeleteBuildSettingsRequest = _reflection.GeneratedProtocolMessageType('DeleteBuildSettingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBUILDSETTINGSREQUEST,
  '__module__' : 'qwak.build_settings.build_settings_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build_settings.DeleteBuildSettingsRequest)
  })
_sym_db.RegisterMessage(DeleteBuildSettingsRequest)

DeleteBuildSettingsResponse = _reflection.GeneratedProtocolMessageType('DeleteBuildSettingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBUILDSETTINGSRESPONSE,
  '__module__' : 'qwak.build_settings.build_settings_api_pb2'
  # @@protoc_insertion_point(class_scope:com.qwak.build_settings.DeleteBuildSettingsResponse)
  })
_sym_db.RegisterMessage(DeleteBuildSettingsResponse)

_BUILDSETTINGSAPI = DESCRIPTOR.services_by_name['BuildSettingsApi']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.qwak.build_settingsB\025BuildSettingsApiProtoP\001'
  _SAVEBUILDSETTINGSREQUEST._serialized_start=115
  _SAVEBUILDSETTINGSREQUEST._serialized_end=229
  _SAVEBUILDSETTINGSRESPONSE._serialized_start=231
  _SAVEBUILDSETTINGSRESPONSE._serialized_end=285
  _GETBUILDSETTINGSREQUEST._serialized_start=287
  _GETBUILDSETTINGSREQUEST._serialized_end=336
  _GETBUILDSETTINGSRESPONSE._serialized_start=338
  _GETBUILDSETTINGSRESPONSE._serialized_end=428
  _DELETEBUILDSETTINGSREQUEST._serialized_start=430
  _DELETEBUILDSETTINGSREQUEST._serialized_end=482
  _DELETEBUILDSETTINGSRESPONSE._serialized_start=484
  _DELETEBUILDSETTINGSRESPONSE._serialized_end=513
  _BUILDSETTINGSAPI._serialized_start=516
  _BUILDSETTINGSAPI._serialized_end=910
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from typing import Optional

from _qwak_proto.qwak.feature_store.sources.batch_pb2 import (
    BatchSource as ProtoBatchSource,
    JdbcSource as ProtoJdbcSource,
    PostgresqlSource as ProtoPostgresqlSource,
)
from _qwak_proto.qwak.feature_store.sources.data_source_pb2 import (
    DataSourceSpec as ProtoDataSourceSpec,
)
from qwak.feature_store.data_sources.batch._jdbc import JdbcSource


@dataclass
class PostgresSource(JdbcSource):
    def _to_proto(self, artifact_url: Optional[str] = None):
        return ProtoDataSourceSpec(
            data_source_repository_name=self.repository,
            batch_source=ProtoBatchSource(
                name=self.name,
                description=self.description,
                date_created_column=self.date_created_column,
                jdbcSource=ProtoJdbcSource(
                    url=self.url,
                    username_secret_name=self.username_secret_name,
                    password_secret_name=self.password_secret_name,
                    db_table=self.db_table,
                    query=self.query,
                    postgresqlSource=ProtoPostgresqlSource(),
                ),
            ),
        )

    @classmethod
    def _from_proto(cls, proto):
        postgresql = proto.jdbcSource
        return cls(
            name=proto.name,
            date_created_column=proto.date_created_column,
            description=proto.description,
            url=postgresql.url,
            username_secret_name=postgresql.username_secret_name,
            password_secret_name=postgresql.password_secret_name,
            db_table=postgresql.db_table,
            query=postgresql.query,
        )
